@@ -1,11 +1,12 @@
 # backend
 from graphgallery.backend.gpu import set_memory_growth
-from graphgallery.backend.config import (epsilon, floatx, intx, backend,
+from graphgallery.backend.config import (epsilon, floatx, intx, backend, POSTFIX,
                                          set_epsilon, set_floatx, set_intx, set_backend)
 
 
-from graphgallery.utils.type_check import (is_list_like, is_scalar_like,
-                                           is_tensor_or_variable, is_interger_scalar)
+from graphgallery.utils.type_check import *
+
+
 
 
 from graphgallery.utils.shape import repeat
@@ -26,10 +27,10 @@ from graphgallery import utils
 from graphgallery import sequence
 from graphgallery import data
 from graphgallery import backend
-from graphgallery import transformers
+from graphgallery import transforms
 
 
-__version__ = '0.3.0'
+__version__ = '0.4.0'
 
 __all__ = ['graphgallery', 'nn', 'utils', 'sequence', 'data',
-           'backend', 'transformers', '__version__']
+           'backend', 'transforms', '__version__']
