@@ -3,10 +3,9 @@ from tensorflow.keras import Model, Input
 from tensorflow.keras.layers import Dropout
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras import regularizers
-from tensorflow.keras.initializers import TruncatedNormal
 from tensorflow.keras.losses import SparseCategoricalCrossentropy
 
-from graphgallery.nn.layers import GraphConvolution, Gather
+from graphgallery.nn.layers.tf_layers import GraphConvolution, Gather
 from graphgallery.nn.models import OBVAT
 from graphgallery.sequence import FullBatchNodeSequence
 from graphgallery.utils.bvat_utils import kl_divergence_with_logit, entropy_y_x, get_normalized_vector
@@ -22,9 +21,9 @@ class SimplifiedOBVAT(OBVAT):
 
     """
 
-    def __init__(self, *graph, adj_transformer="normalize_adj", attr_transformer=None,
+    def __init__(self, *graph, adj_transform="normalize_adj", attr_transform=None,
                  device='cpu:0', seed=None, name=None, **kwargs):
-        """Creat a Simplified OBVAT model.
+        """Create a Simplified OBVAT model.
 
         This can be instantiated in several ways:
 
@@ -41,12 +40,12 @@ class SimplifiedOBVAT(OBVAT):
         ----------
         graph: An instance of `graphgallery.data.Graph` or a tuple(list) of inputs.
             A sparse, attributed, labeled graph.
-        adj_transformer: string, `transformer`, or None. optional
-            How to transform the adjacency matrix. See `graphgallery.transformers`
+        adj_transform: string, `transform`, or None. optional
+            How to transform the adjacency matrix. See `graphgallery.transforms`
             (default: : obj: `'normalize_adj'` with normalize rate `- 0.5`.
             i.e., math:: \hat{A} = D^{-\frac{1}{2}} A D^{-\frac{1}{2}})
-        attr_transformer: string, transformer, or None. optional
-            How to transform the node attribute matrix. See `graphgallery.transformers`
+        attr_transform: string, `transform`, or None. optional
+            How to transform the node attribute matrix. See `graphgallery.transforms`
             (default: obj: `None`)
         device: string. optional
             The device where the model is running on. You can specified `CPU` or `GPU`
@@ -57,20 +56,20 @@ class SimplifiedOBVAT(OBVAT):
             multiple calls. (default: obj: `None`, i.e., using random seed)
         name: string. optional
             Specified name for the model. (default: : str: `class.__name__`)
-        kwargs: other customed keyword Parameters.
+        kwargs: other customized keyword Parameters.
 
         Note:
         ----------
         This is a simplified implementation of `OBVAT`.                
         """
         super().__init__(*graph,
-                         adj_transformer=adj_transformer, attr_transformer=attr_transformer,
+                         adj_transform=adj_transform, attr_transform=attr_transform,
                          device=device, seed=seed, name=name, **kwargs)
 
     # use decorator to make sure all list arguments have the same length
     @EqualVarLength()
-    def build(self, hiddens=[16], activations=['relu'], dropouts=[0.],
-              lr=0.01, l2_norms=[5e-4], p1=1.4, p2=0.7, use_bias=False,
+    def build(self, hiddens=[16], activations=['relu'], dropout=0.,
+              lr=0.01, l2_norm=5e-4, p1=1.4, p2=0.7, use_bias=False,
               epsilon=0.01):
 
         with tf.device(self.device):
@@ -83,18 +82,16 @@ class SimplifiedOBVAT(OBVAT):
                           dtype=self.intx, name='node_index')
 
             GCN_layers = []
-            dropout_layers = []
-            for hid, activation, dropout, l2_norm in zip(hiddens, activations, dropouts, l2_norms):
-                GCN_layers.append(GraphConvolution(hid,
+            for hidden, activation in zip(hiddens, activations):
+                GCN_layers.append(GraphConvolution(hidden,
                                                    activation=activation,
                                                    use_bias=use_bias,
                                                    kernel_regularizer=regularizers.l2(l2_norm)))
-                dropout_layers.append(Dropout(rate=dropout))
 
-            GCN_layers.append(GraphConvolution(
-                self.graph.n_classes, use_bias=use_bias))
+            GCN_layers.append(GraphConvolution(self.graph.n_classes, use_bias=use_bias))
+            
             self.GCN_layers = GCN_layers
-            self.dropout_layers = dropout_layers
+            self.dropout = Dropout(rate=dropout)
 
             logit = self.forward(x, adj)
             output = Gather()([logit, index])
@@ -106,15 +103,14 @@ class SimplifiedOBVAT(OBVAT):
             entropy_loss = entropy_y_x(logit)
             vat_loss = self.virtual_adversarial_loss(x, adj, logit, epsilon)
             model.add_loss(p1 * vat_loss + p2 * entropy_loss)
-
+        
             self.model = model
-            self.adv_optimizer = Adam(lr=lr / 10)
 
     def train_step(self, sequence):
         return super(OBVAT, self).train_step(sequence)
 
     def virtual_adversarial_loss(self, x, adj, logit, epsilon):
-        d = tf.random.normal(shape=tf.shape(x), dtype=self.floatx)
+        d = tf.random.normal(shape=[self.graph.n_nodes, self.graph.n_attrs], dtype=self.floatx)
 
         r_vadv = get_normalized_vector(d) * epsilon
         logit_p = tf.stop_gradient(logit)
