@@ -11,9 +11,10 @@ from graphgallery.utils import save
 
 
 class TorchKerasModel(Module):
-    """Keras like PyTorch Model"""
+    """Keras like PyTorch Model."""
 
     def __init__(self, *args, **kwargs):
+
         super().__init__(*args, **kwargs)
 
         # To be compatible with TensorFlow
@@ -25,7 +26,7 @@ class TorchKerasModel(Module):
 
     def compile(self):
         ...
-        
+
     def summary(self):
         ...
 
@@ -34,6 +35,10 @@ class TorchKerasModel(Module):
 
     def save(self, filepath, overwrite=True, save_format=None, **kwargs):
         save.save_torch_model(self, filepath, overwrite=overwrite, save_format=save_format, **kwargs)
+        
+    def reset_parameters(self):
+        for layer in self.layers:
+            layer.reset_parameters()        
 
 
 def dummy_function(*args, **kwargs):
